@@ -10,11 +10,22 @@ Usage::
     client: BatchClient = boto3.client("batch")
     ```
 """
-import sys
 from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
+from mypy_boto3_batch.literals import (
+    CEState,
+    CEType,
+    DescribeComputeEnvironmentsPaginatorName,
+    DescribeJobDefinitionsPaginatorName,
+    DescribeJobQueuesPaginatorName,
+    JobDefinitionType,
+    JobStatus,
+    JQState,
+    ListJobsPaginatorName,
+    PlatformCapability,
+)
 from mypy_boto3_batch.paginator import (
     DescribeComputeEnvironmentsPaginator,
     DescribeJobDefinitionsPaginator,
@@ -47,12 +58,6 @@ from mypy_boto3_batch.type_defs import (
     UpdateJobQueueResponseTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("BatchClient",)
 
 
@@ -91,8 +96,8 @@ class BatchClient:
     def create_compute_environment(
         self,
         computeEnvironmentName: str,
-        type: Literal["MANAGED", "UNMANAGED"],
-        state: Literal["ENABLED", "DISABLED"] = None,
+        type: CEType,
+        state: CEState = None,
         computeResources: "ComputeResourceTypeDef" = None,
         serviceRole: str = None,
         tags: Dict[str, str] = None,
@@ -106,7 +111,7 @@ class BatchClient:
         jobQueueName: str,
         priority: int,
         computeEnvironmentOrder: List["ComputeEnvironmentOrderTypeDef"],
-        state: Literal["ENABLED", "DISABLED"] = None,
+        state: JQState = None,
         tags: Dict[str, str] = None,
     ) -> CreateJobQueueResponseTypeDef:
         """
@@ -175,9 +180,7 @@ class BatchClient:
         jobQueue: str = None,
         arrayJobId: str = None,
         multiNodeJobId: str = None,
-        jobStatus: Literal[
-            "SUBMITTED", "PENDING", "RUNNABLE", "STARTING", "RUNNING", "SUCCEEDED", "FAILED"
-        ] = None,
+        jobStatus: JobStatus = None,
         maxResults: int = None,
         nextToken: str = None,
     ) -> ListJobsResponseTypeDef:
@@ -193,7 +196,7 @@ class BatchClient:
     def register_job_definition(
         self,
         jobDefinitionName: str,
-        type: Literal["container", "multinode"],
+        type: JobDefinitionType,
         parameters: Dict[str, str] = None,
         containerProperties: "ContainerPropertiesTypeDef" = None,
         nodeProperties: "NodePropertiesTypeDef" = None,
@@ -201,7 +204,7 @@ class BatchClient:
         propagateTags: bool = None,
         timeout: "JobTimeoutTypeDef" = None,
         tags: Dict[str, str] = None,
-        platformCapabilities: List[Literal["EC2", "FARGATE"]] = None,
+        platformCapabilities: List[PlatformCapability] = None,
     ) -> RegisterJobDefinitionResponseTypeDef:
         """
         [Client.register_job_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/batch.html#Batch.Client.register_job_definition)
@@ -244,7 +247,7 @@ class BatchClient:
     def update_compute_environment(
         self,
         computeEnvironment: str,
-        state: Literal["ENABLED", "DISABLED"] = None,
+        state: CEState = None,
         computeResources: ComputeResourceUpdateTypeDef = None,
         serviceRole: str = None,
     ) -> UpdateComputeEnvironmentResponseTypeDef:
@@ -255,7 +258,7 @@ class BatchClient:
     def update_job_queue(
         self,
         jobQueue: str,
-        state: Literal["ENABLED", "DISABLED"] = None,
+        state: JQState = None,
         priority: int = None,
         computeEnvironmentOrder: List["ComputeEnvironmentOrderTypeDef"] = None,
     ) -> UpdateJobQueueResponseTypeDef:
@@ -265,7 +268,7 @@ class BatchClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["describe_compute_environments"]
+        self, operation_name: DescribeComputeEnvironmentsPaginatorName
     ) -> DescribeComputeEnvironmentsPaginator:
         """
         [Paginator.DescribeComputeEnvironments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/batch.html#Batch.Paginator.DescribeComputeEnvironments)
@@ -273,7 +276,7 @@ class BatchClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["describe_job_definitions"]
+        self, operation_name: DescribeJobDefinitionsPaginatorName
     ) -> DescribeJobDefinitionsPaginator:
         """
         [Paginator.DescribeJobDefinitions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/batch.html#Batch.Paginator.DescribeJobDefinitions)
@@ -281,14 +284,14 @@ class BatchClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["describe_job_queues"]
+        self, operation_name: DescribeJobQueuesPaginatorName
     ) -> DescribeJobQueuesPaginator:
         """
         [Paginator.DescribeJobQueues documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/batch.html#Batch.Paginator.DescribeJobQueues)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["list_jobs"]) -> ListJobsPaginator:
+    def get_paginator(self, operation_name: ListJobsPaginatorName) -> ListJobsPaginator:
         """
         [Paginator.ListJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/batch.html#Batch.Paginator.ListJobs)
         """
