@@ -22,11 +22,11 @@ Usage::
     list_jobs_paginator: ListJobsPaginator = client.get_paginator("list_jobs")
     ```
 """
-import sys
 from typing import Iterator, List
 
 from botocore.paginate import Paginator as Boto3Paginator
 
+from mypy_boto3_batch.literals import JobStatus
 from mypy_boto3_batch.type_defs import (
     DescribeComputeEnvironmentsResponseTypeDef,
     DescribeJobDefinitionsResponseTypeDef,
@@ -35,12 +35,6 @@ from mypy_boto3_batch.type_defs import (
     PaginatorConfigTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = (
     "DescribeComputeEnvironmentsPaginator",
     "DescribeJobDefinitionsPaginator",
@@ -102,9 +96,7 @@ class ListJobsPaginator(Boto3Paginator):
         jobQueue: str = None,
         arrayJobId: str = None,
         multiNodeJobId: str = None,
-        jobStatus: Literal[
-            "SUBMITTED", "PENDING", "RUNNABLE", "STARTING", "RUNNING", "SUCCEEDED", "FAILED"
-        ] = None,
+        jobStatus: JobStatus = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListJobsResponseTypeDef]:
         """
